==> indigitall_flutter_plugin-2.0.2.tar.gz: android/src/main/kotlin/com/indigitall/indigitall_flutter_plugin/IndigitallCustomerFlutterPlugin.kt <==
package com.indigitall.indigitall_flutter_plugin

import android.content.Context
import android.media.midi.MidiManager
import androidx.core.content.ContextCompat
import com.indigitall.android.Indigitall
import com.indigitall.android.callbacks.DeviceCallback
import com.indigitall.android.commons.models.Channel
import com.indigitall.android.commons.models.ErrorModel
import com.indigitall.android.customer.CustomerIndigitall
import com.indigitall.android.customer.callbacks.CustomerCallback
import com.indigitall.android.customer.callbacks.CustomerFieldCallback
import com.indigitall.android.customer.models.Customer
import com.indigitall.android.customer.models.CustomerField
import com.indigitall.android.models.Device
import com.indigitall.indigitall_flutter_plugin.utils.CustomerParse
import io.flutter.plugin.common.MethodChannel.Result
import org.json.JSONArray
import org.json.JSONException
import org.json.JSONObject

class IndigitallCustomerFlutterPlugin(val context: Context) {


    private val CALLBACK_CUSTOMER_FIELDS = "callbackCustomerFields"

    fun getCustomer(result: Result) {
        CustomerIndigitall.getCustomer(context, object: CustomerCallback(context) {
            override fun onError(error: ErrorModel?) {
                ContextCompat.getMainExecutor(context).execute {
                    error?.errorCode?.name?.let{result.error(it, error.errorMessage.errorMessage, null)}
                }
            }

            override fun onSuccess(customer: Customer) {
                ContextCompat.getMainExecutor(context).execute {
                    result.success(CustomerParse.mapFromCustomer(customer))
                }
            }

        })
    }

    fun getCustomerInformation(arguments: Any?, result: Result) {
        arguments?.let{
            val jsonArray = JSONArray(it as List<*>)
            val customerFields = CustomerParse.parseCustomerArray(jsonArray)
            CustomerIndigitall.getCustomerInformation(context, customerFields, object : CustomerFieldCallback(context){
                override fun onError(error: ErrorModel?) {
                    ContextCompat.getMainExecutor(context).execute {
                        error?.errorCode?.name?.let{result.error(it, error.errorMessage.errorMessage, null)}
                    }
                }

                override fun onSuccess(customerField: ArrayList<CustomerField>) {
                    ContextCompat.getMainExecutor(context).execute {
                        result.success(CustomerParse.customerFieldToMap(CALLBACK_CUSTOMER_FIELDS, CustomerParse.listFromCustomerArray(customerField)))
                    }
                }

            })
        }
    }

    fun link(arguments: Any?, result: Result) {
        arguments?.let{
            val params = JSONObject(it as Map<*, *>)
            var externalId = ""
            var channel = Channel.PUSH
            if (params.has("channel")) channel = getChannel(params.getString("channel"))
            if (params.has("externalId")) externalId = params.getString("externaId")
            Indigitall.logIn(context, externalId, object: DeviceCallback(context){
                override fun onSuccess(p0: Device?) {
                    CustomerIndigitall.linkCustomer(context, channel, object : CustomerCallback(context){
                        override fun onError(error: ErrorModel?) {
                            ContextCompat.getMainExecutor(context).execute {
                                error?.errorCode?.name?.let{result.error(it, error.errorMessage.errorMessage, null)}
                            }
                        }

                        override fun onSuccess(customer: Customer) {
                            ContextCompat.getMainExecutor(context).execute {
                                result.success("")
                            }
                        }

                    })
                }

                override fun onFail(error: ErrorModel?) {
                    ContextCompat.getMainExecutor(context).execute {
                        error?.errorCode?.name?.let{result.error(it, error.errorMessage.errorMessage, null)}
                    }
                }

            })

        }
    }

    fun unlink(arguments: Any?, result: Result) {
        arguments?.let{
            val params = JSONObject(it as Map<*, *>)
            var channel = Channel.PUSH
            if (params.has("channel")) channel = getChannel(params.getString("channel"))
            Indigitall.logOut(context, object: DeviceCallback(context){
                override fun onSuccess(p0: Device?) {
                    CustomerIndigitall.linkCustomer(context, channel, object : CustomerCallback(context){
                        override fun onError(error: ErrorModel?) {
                            ContextCompat.getMainExecutor(context).execute {
                                error?.errorCode?.name?.let{result.error(it, error.errorMessage.errorMessage, null)}
                            }
                        }

                        override fun onSuccess(customer: Customer) {
                            ContextCompat.getMainExecutor(context).execute {
                                result.success("")
                            }
                        }

                    })
                }

                override fun onFail(error: ErrorModel?) {
                    ContextCompat.getMainExecutor(context).execute {
                        error?.errorCode?.name?.let{result.error(it, error.errorMessage.errorMessage, null)}
                    }
                }

            })

        }
    }

    fun assignOrUpdateValueToCustomerFields(arguments: Any?, result: Result) {
        arguments?.let{
            val params = JSONObject(it as Map<*, *>)
            CustomerIndigitall.updateValueToCustomerFields(context, params, object: CustomerCallback(context) {
                override fun onError(error: ErrorModel?) {
                    ContextCompat.getMainExecutor(context).execute {
                        error?.errorCode?.name?.let{result.error(it, error.errorMessage.errorMessage, null)}
                    }
                }

                override fun onSuccess(customer: Customer) {
                    ContextCompat.getMainExecutor(context).execute {
                        result.success(CustomerParse.mapFromCustomer(customer))
                    }
                }

            })
        }
    }

    fun deleteValuesFromCustomerFields(arguments: Any?, result: Result) {
        arguments?.let{
            val jsonArray = JSONArray(it as List<*>)
            CustomerIndigitall.deleteValuesFromCustomerFields(context, CustomerParse.parseCustomerArray(jsonArray), object: CustomerCallback(context) {
                override fun onError(error: ErrorModel?) {
                    ContextCompat.getMainExecutor(context).execute {
                        error?.errorCode?.name?.let{result.error(it, error.errorMessage.errorMessage, null)}
                    }
                }

                override fun onSuccess(customer: Customer) {
                    ContextCompat.getMainExecutor(context).execute {
                        result.success(CustomerParse.mapFromCustomer(customer))
                    }
                }

            })
        }
    }


    private fun getChannel(channel: String): Channel {
        return when (channel) {
            "inapp" -> {
                Channel.INAPP
            }
            "chat" -> {
                Channel.CHAT
            }
            else -> Channel.PUSH
        }
    }


}

==> indigitall_flutter_plugin-2.5.1.tar.gz: android/src/main/kotlin/com/indigitall/indigitall_flutter_plugin/IndigitallCustomerFlutterPlugin.kt <==
package com.indigitall.indigitall_flutter_plugin

import android.content.Context
import android.media.midi.MidiManager
import androidx.core.content.ContextCompat
import com.indigitall.android.Indigitall
import com.indigitall.android.push.callbacks.DeviceCallback
import com.indigitall.android.commons.models.Channel
import com.indigitall.android.commons.models.ErrorModel
import com.indigitall.android.customer.CustomerIndigitall
import com.indigitall.android.customer.callbacks.CustomerCallback
import com.indigitall.android.customer.callbacks.CustomerFieldCallback
import com.indigitall.android.customer.models.Customer
import com.indigitall.android.customer.models.CustomerField
import com.indigitall.android.push.models.Device
import com.indigitall.indigitall_flutter_plugin.utils.CustomerParse
import io.flutter.plugin.common.MethodChannel.Result
import org.json.JSONArray
import org.json.JSONException
import org.json.JSONObject

class IndigitallCustomerFlutterPlugin(val context: Context) {


    private val CALLBACK_CUSTOMER_FIELDS = "callbackCustomerFields"

    fun getCustomer(result: Result) {
        CustomerIndigitall.getCustomer(context, object: CustomerCallback(context) {
            override fun onError(error: ErrorModel?) {
                ContextCompat.getMainExecutor(context).execute {
                    error?.errorCode?.name?.let{result.error(it, error.errorMessage.errorMessage, null)}
                }
            }

            override fun onSuccess(customer: Customer) {
                ContextCompat.getMainExecutor(context).execute {
                    result.success(CustomerParse.mapFromCustomer(customer))
                }
            }

        })
    }

    fun getCustomerInformation(arguments: Any?, result: Result) {
        arguments?.let{
            val jsonArray = JSONArray(it as List<*>)
            val customerFields = CustomerParse.parseCustomerArray(jsonArray)
            CustomerIndigitall.getCustomerInformation(context, customerFields, object : CustomerFieldCallback(context){
                override fun onError(error: ErrorModel?) {
                    ContextCompat.getMainExecutor(context).execute {
                        error?.errorCode?.name?.let{result.error(it, error.errorMessage.errorMessage, null)}
                    }
                }

                override fun onSuccess(customerField: ArrayList<CustomerField>) {
                    ContextCompat.getMainExecutor(context).execute {
                        result.success(CustomerParse.customerFieldToMap(CALLBACK_CUSTOMER_FIELDS, CustomerParse.listFromCustomerArray(customerField)))
                    }
                }

            })
        }
    }

    fun link(arguments: Any?, result: Result) {
        arguments?.let{
            val params = JSONObject(it as Map<*, *>)
            var externalId = ""
            var channel = Channel.PUSH
            if (params.has("channel")) channel = getChannel(params.getString("channel"))
            if (params.has("externalId")) externalId = params.getString("externaId")
            Indigitall.logIn(context, externalId, object: DeviceCallback(context){
                override fun onSuccess(p0: Device?) {
                    CustomerIndigitall.link(context, channel, object : CustomerCallback(context){
                        override fun onError(error: ErrorModel?) {
                            ContextCompat.getMainExecutor(context).execute {
                                error?.errorCode?.name?.let{result.error(it, error.errorMessage.errorMessage, null)}
                            }
                        }

                        override fun onSuccess(customer: Customer) {
                            ContextCompat.getMainExecutor(context).execute {
                                result.success("")
                            }
                        }

                    })
                }

                override fun onFail(error: ErrorModel?) {
                    ContextCompat.getMainExecutor(context).execute {
                        error?.errorCode?.name?.let{result.error(it, error.errorMessage.errorMessage, null)}
                    }
                }

            })

        }
    }

    fun unlink(arguments: Any?, result: Result) {
        arguments?.let{
            val params = JSONObject(it as Map<*, *>)
            var channel = Channel.PUSH
            if (params.has("channel")) channel = getChannel(params.getString("channel"))
            Indigitall.logOut(context, object: DeviceCallback(context){
                override fun onSuccess(p0: Device?) {
                    CustomerIndigitall.link(context, channel, object : CustomerCallback(context){
                        override fun onError(error: ErrorModel?) {
                            ContextCompat.getMainExecutor(context).execute {
                                error?.errorCode?.name?.let{result.error(it, error.errorMessage.errorMessage, null)}
                            }
                        }

                        override fun onSuccess(customer: Customer) {
                            ContextCompat.getMainExecutor(context).execute {
                                result.success("")
                            }
                        }

                    })
                }

                override fun onFail(error: ErrorModel?) {
                    ContextCompat.getMainExecutor(context).execute {
                        error?.errorCode?.name?.let{result.error(it, error.errorMessage.errorMessage, null)}
                    }
                }

            })

        }
    }

    fun assignOrUpdateValueToCustomerFields(arguments: Any?, result: Result) {
        arguments?.let{
            val params = JSONObject(it as Map<*, *>)
            CustomerIndigitall.updateValueToCustomerFields(context, params, object: CustomerCallback(context) {
                override fun onError(error: ErrorModel?) {
                    ContextCompat.getMainExecutor(context).execute {
                        error?.errorCode?.name?.let{result.error(it, error.errorMessage.errorMessage, null)}
                    }
                }

                override fun onSuccess(customer: Customer) {
                    ContextCompat.getMainExecutor(context).execute {
                        result.success(CustomerParse.mapFromCustomer(customer))
                    }
                }

            })
        }
    }

    fun deleteValuesFromCustomerFields(arguments: Any?, result: Result) {
        arguments?.let{
            val jsonArray = JSONArray(it as List<*>)
            CustomerIndigitall.deleteValuesFromCustomerFields(context, CustomerParse.parseCustomerArray(jsonArray), object: CustomerCallback(context) {
                override fun onError(error: ErrorModel?) {
                    ContextCompat.getMainExecutor(context).execute {
                        error?.errorCode?.name?.let{result.error(it, error.errorMessage.errorMessage, null)}
                    }
                }

                override fun onSuccess(customer: Customer) {
                    ContextCompat.getMainExecutor(context).execute {
                        result.success(CustomerParse.mapFromCustomer(customer))
                    }
                }

            })
        }
    }


    private fun getChannel(channel: String): Channel {
        return when (channel) {
            "inapp" -> {
                Channel.INAPP
            }
            "chat" -> {
                Channel.CHAT
            }
            else -> Channel.PUSH
        }
    }


}
